@@ -253,7 +253,8 @@ class TCPDriver(Driver):
         except (socket.error, socket.timeout):
             self._sock = None  # don't want to hang on to bad socket
             raise
-
+        # set socket for tcp keepalive
+        self._sock.setsockopt(socket.IPPROTO_TCP, socket.SO_KEEPALIVE, 1)
         if self.disable_nagle:
             # disable nagle, as memcache deals with lots of small packets.
             self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
